@@ -26,10 +26,6 @@
 
 static void app_resizer_class_init (AppResizerClass *);
 static void app_resizer_init (AppResizer *);
-#if !GTK_CHECK_VERSION (3, 0, 0)
-static void app_resizer_destroy (GtkObject *);
-#endif
-
 static void app_resizer_size_allocate (GtkWidget * resizer, GtkAllocation * allocation);
 #if GTK_CHECK_VERSION (3, 0, 0)
 static gboolean app_resizer_paint_window (GtkWidget * widget, cairo_t * cr, AppShellData * app_data);
@@ -45,10 +41,6 @@ app_resizer_class_init (AppResizerClass * klass)
 {
 	GtkWidgetClass *widget_class;
 
-#if !GTK_CHECK_VERSION (3, 0, 0)
-	((GtkObjectClass *) klass)->destroy = app_resizer_destroy;
-#endif
-
 	widget_class = GTK_WIDGET_CLASS (klass);
 	widget_class->size_allocate = app_resizer_size_allocate;
 }
@@ -56,6 +48,10 @@ app_resizer_class_init (AppResizerClass * klass)
 static void
 app_resizer_init (AppResizer * window)
 {
+#if GTK_CHECK_VERSION (3, 0, 0)
+    gtk_style_context_add_class (gtk_widget_get_style_context (GTK_WIDGET (window)),
+                                 GTK_STYLE_CLASS_VIEW);
+#endif
 }
 
 void
@@ -306,13 +302,6 @@ app_resizer_new (GtkVBox * child, gint initial_num_columns, gboolean homogeneous
 	return GTK_WIDGET (widget);
 }
 
-#if !GTK_CHECK_VERSION (3, 0, 0)
-static void
-app_resizer_destroy (GtkObject * obj)
-{
-}
-#endif
-
 void
 app_resizer_set_vadjustment_value (GtkWidget * widget, gdouble value)
 {
@@ -340,16 +329,17 @@ app_resizer_paint_window (GtkWidget * widget, GdkEventExpose * event, AppShellDa
 	*/
 
 #if GTK_CHECK_VERSION (3, 0, 0)
-	GdkRectangle rect;
-	gdk_cairo_get_clip_rectangle (cr, &rect);
+	cairo_save(cr);
+
+	GtkAllocation widget_allocation;
+	gtk_widget_get_allocation (widget, &widget_allocation);
 
 	gdk_cairo_set_source_color (cr, gtk_widget_get_style (widget)->base);
 	cairo_set_line_width(cr, 1);
 
-	cairo_rectangle(cr, 0, 0, rect.width, rect.height);
+	cairo_rectangle(cr, widget_allocation.x, widget_allocation.y, widget_allocation.width, widget_allocation.height);
 	cairo_stroke_preserve(cr);
 	cairo_fill(cr);
-
 #else
 	gdk_draw_rectangle (GTK_LAYOUT (widget)->bin_window,
 		widget->style->base_gc[GTK_STATE_NORMAL], TRUE, event->area.x, event->area.y,
@@ -360,16 +350,14 @@ app_resizer_paint_window (GtkWidget * widget, GdkEventExpose * event, AppShellDa
 	{
 		GtkWidget *selected_widget = GTK_WIDGET (app_data->selected_group);
 #if GTK_CHECK_VERSION (3, 0, 0)
-		GtkAllocation widget_allocation;
 		GtkAllocation selected_widget_allocation;
 
-		gtk_widget_get_allocation (widget, &widget_allocation);
 		gtk_widget_get_allocation (selected_widget, &selected_widget_allocation);
 
 		gdk_cairo_set_source_color (cr, gtk_widget_get_style (selected_widget)->light);
 		cairo_set_line_width(cr, 1);
 
-		cairo_rectangle(cr, selected_widget_allocation.x, selected_widget_allocation.y, widget_allocation.width, selected_widget_allocation.height);
+		cairo_rectangle(cr, selected_widget_allocation.x, selected_widget_allocation.y, selected_widget_allocation.width, selected_widget_allocation.height);
 		cairo_stroke_preserve(cr);
 		cairo_fill(cr);
 #else
@@ -381,5 +369,9 @@ app_resizer_paint_window (GtkWidget * widget, GdkEventExpose * event, AppShellDa
 #endif
 	}
 
+#if GTK_CHECK_VERSION (3, 0, 0)
+	cairo_restore(cr);
+#endif
+
 	return FALSE;
 }
