@@ -3,9 +3,9 @@
 
 #include <glib.h>
 #include <gtk/gtk.h>
-#include <libmate/mate-desktop-item.h>
+#include <libmate-desktop/mate-desktop-item.h>
 #define MATE_DESKTOP_USE_UNSTABLE_API 1
-#include <libmateui/mate-desktop-thumbnail.h>
+#include <libmate-desktop/mate-desktop-thumbnail.h>
 
 #ifdef __cplusplus
 extern "C" {
